"""
MyUI plugin base. Easy way to structure a new plugin.
Remember to inherit and use all functions upon needs.
"""
import pygame
from typing import Optional, Protocol

class Plugin(Protocol):
    def on_load(self, app) -> None: ...
    def on_unload(self) -> None: ...
    def on_update(self) -> None: ...
    def on_render(self, surface: pygame.Surface) -> None: ...
    def on_event(self, event: pygame.event.Event, offset: pygame.math.Vector2) -> Optional[bool]: ...

del Optional


"""
Use plugins to optimize adding utilities to a app in MyUI.
"""

from .plugin_base import Plugin as PluginBase
from .plugin_loader import PluginWrapper, load_plugins_from, create_dict, get_plugin_group
from typing import Union

component = Union[PluginBase, PluginWrapper]

del Union

print("- MyUI plugin loader")


"""
For reaccuring values, you may predefine them before 
setting up your app and its correlating components.
"""

from dataclasses import dataclass
from typing import Optional, Tuple, Union
import pygame

InputColor = Union[Tuple[int, int, int], pygame.Color]

@dataclass
class FontScheme:
    title: Optional[pygame.font.Font] = None
    large: Optional[pygame.font.Font] = None
    medium1: Optional[pygame.font.Font] = None
    medium2: Optional[pygame.font.Font] = None
    small1: Optional[pygame.font.Font] = None
    small2: Optional[pygame.font.Font] = None

@dataclass
class Theme:
    text_color: Optional[InputColor] = None
    background: Optional[InputColor] = None
    border_color: Optional[InputColor] = None

component = Union[FontScheme, Theme]

del InputColor, Tuple, Union, Optional, dataclass

print("- MyUI preseting")